@@ -14,8 +14,7 @@ from wsgiref.simple_server import make_server, WSGIServer, WSGIRequestHandler
 
 from Cryptodome.Protocol.KDF import scrypt
 from Cryptodome.Random import get_random_bytes
-from bottle import Bottle, request, abort, HTTPError
-
+from bottle import Bottle, request, redirect, abort, HTTPError
 from myjd_api.common import check_ip
 from myjd_api.common import decode_base64
 from myjd_api.config import Config
@@ -103,10 +102,10 @@ def app_container(port, configfile, _device):
         auth_user = _config.get('auth_user')
         auth_hash = _config.get('auth_hash')
         if auth_user and auth_hash:
-            if auth_hash and "srcypt|" not in auth_hash:
+            if auth_hash and "scrypt|" not in auth_hash:
                 salt = get_random_bytes(16).hex()
                 key = scrypt(auth_hash, salt, 16, N=2 ** 14, r=8, p=1).hex()
-                auth_hash = "srcypt|" + salt + "|" + key
+                auth_hash = "scrypt|" + salt + "|" + key
                 _config.save("auth_hash", to_str(auth_hash))
             secrets = auth_hash.split("|")
             salt = secrets[1]
@@ -144,6 +143,17 @@ def app_container(port, configfile, _device):
         else:
             return abort(400, "Failed")
 
+    @app.hook('before_request')
+    def redirect_without_trailing_slash():
+        no_trailing_slash = [
+            "/api/myjd_move/",
+            "/api/myjd_remove/",
+            "/api/myjd_retry/",
+            "/api/myjd_pause/"
+        ]
+        if not request.path.endswith('/') and not any(s in request.path for s in no_trailing_slash):
+            raise redirect(request.url + '/')
+
     @app.get("/myjd_state/")
     @auth_basic(is_authenticated_user)
     def myjd_state():
